@@ -1,6 +1,11 @@
 from markdownify import markdownify as md
 
 
+def test_asterisks():
+    assert md('*hey*dude*') == r'\*hey\*dude\*'
+    assert md('*hey*dude*', escape_asterisks=False) == r'*hey*dude*'
+
+
 def test_underscore():
     assert md('_hey_dude_') == r'\_hey\_dude\_'
     assert md('_hey_dude_', escape_underscores=False) == r'_hey_dude_'
